@@ -7,7 +7,7 @@ for source in "$@"; do
 	*Makefile|*makefile) 
         source-highlight --failsafe -f esc --lang-def=makefile.lang --style-file=esc.style -i "$source" ;;
 	*.tar|*.tgz|*.gz|*.bz2|*.xz)
-        lesspipe "$source" ;;
+        lesspipe.sh "$source" ;;
         *) source-highlight --failsafe --infer-lang -f esc --style-file=esc.style -i "$source" ;;
     esac
 done
